@@ -5,7 +5,12 @@ import h5py
 from matplotlib import pyplot as plt
 import nibabel as nib
 from azure.storage.blob import BlobServiceClient, BlobClient, ContainerClient, __version__
-from mrftools import SyntheticSequenceType
+from mrftools import SyntheticSequenceType, DatasetManager, SimpleITKRunner
+import numpy as np
+import tensorflow as tf
+from tensorflow import keras
+import tarfile
+import os.path
 
 class BlochSyntheticGenerator: 
     def __init__(self,type:SyntheticSequenceType,TR,TE,TI_1=-1, TI_2=-1):
@@ -85,13 +90,6 @@ class BlochSyntheticGenerator:
         print("Finished simulation")
         return output_lin.reshape(T1s.shape)
 
-from mrftools import SyntheticSequenceType, DatasetManager, BlochSyntheticGenerator, SimpleITKRunner
-import numpy as np
-import tensorflow as tf
-from tensorflow import keras
-import tarfile
-import os.path
-
 class AISyntheticGenerator: 
     def __init__(self,name,description, referenceBlochGenerator:BlochSyntheticGenerator=None, normalizeM0=True, normalizeTargetSeries=True):
         self.name = name   
